<?php
/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
include ("application.inc.php");
if ($SESSION["frames_used"]) {
?>

<html>
<frameset cols="180,*" framespacing=0 frameborder=no border=0>
<frame name="categories" src="shopping/navigation.php" target="bodyframe">
<frame name="bodyframe" src="<?php echo "$CFG->firstpage"; ?>">
</frameset>
</html>

<?php
} else redirect("$CFG->firstpage");
?>
